parse

Function parse 

pub fn parse<P, Token, Error>(tokens: Vec<Token>) -> Result<P::Root, Error>
where P: Parser<Token, Error>,
Parse a vec of tokens into the provided root AST node.

Type Parameters

  • P: The parser used to parse the tokens.
  • Token: The type of token being parsed.
  • Error: The error type that can be returned from parsing.